@@ -13,7 +13,7 @@ from .metrics import create_metric_by_name
 from .losses import create_loss_by_name
 from .optimizers import create_optimizer_by_name
 
-__version__ = '0.4.1'
+__version__ = '0.4.5'
 
 class Model(torch.nn.Module):
     """
@@ -58,22 +58,23 @@ class Model(torch.nn.Module):
 
     @torch.no_grad()
     def build(self, input_shape):
-        """Builds the model when it contains `KerasLayer`."""
-        input_shape = [2] + list(input_shape)
-        probe_input = torch.zeros(size=input_shape)
-        self.model.forward(probe_input)
+        """Build the model when it contains `KerasLayer`."""
+        if self.has_keras_layer:
+            input_shape = [2] + list(input_shape)
+            probe_input = torch.zeros(size=input_shape)
+            self.model.forward(probe_input)
         self.built = True
         return self
 
     def summary(self, input_shape, depth=3):
-        """Prints a string summary of the network."""
+        """Print a string summary of the network."""
         if self.has_keras_layer and not self.built:
             raise AssertionError("You should call `model.build()` first because the model contains `KerasLayer`.")
         torchsummary.summary(self.model, input_shape, depth=depth, verbose=1)
 
     def compile(self, optimizer, loss, metrics=None, device=None):
         """
-        Configures the model for training.
+        Configure the model for training.
 
         Args:
 
@@ -118,13 +119,13 @@ class Model(torch.nn.Module):
 
 
     def fit(self, x, y, epochs, batch_size=32,
-                validation_split=None, val_split_seed=None,
+                validation_split=None, val_split_seed=7,
                 validation_data=None,
                 callbacks=[],
                 verbose=1,
                 precise_mode=False,
                 ):
-        """Trains the model for a fixed number of epochs (iterations on a dataset)."""
+        """Train the model for a fixed number of epochs (iterations on a dataset)."""
 
         assert self.compiled
         x, y = self.to_tensor(x, y)
@@ -141,10 +142,7 @@ class Model(torch.nn.Module):
         if validation_split != None:
             val_length = int(len(train_set) * validation_split)
             train_length = len(train_set) - val_length
-            if val_split_seed != None:
-                train_set, val_set = random_split(train_set, [train_length, val_length], generator=torch.Generator().manual_seed(val_split_seed))
-            else:
-                train_set, val_set = random_split(train_set, [train_length, val_length])
+            train_set, val_set = random_split(train_set, [train_length, val_length], generator=torch.Generator().manual_seed(val_split_seed))
 
         train_loader = DataLoader(train_set, batch_size=batch_size, shuffle=True)
         val_loader = DataLoader(val_set, batch_size=batch_size, shuffle=False) if has_val else None
@@ -157,15 +155,15 @@ class Model(torch.nn.Module):
 
     @torch.no_grad()
     def evaluate(self, x, y, batch_size=32):
-        """Returns the loss value & metrics values for the model in test mode.\n\n    Computation is done in batches."""
+        """Return the loss value & metrics values for the model in test mode.\n\n    Computation is done in batches."""
         assert self.compiled
         x, y = self.to_tensor(x, y)
         val_loader = DataLoader(TensorDataset(x, y), batch_size=batch_size, shuffle=False)
         return self.trainer.evaluate(val_loader)
 
     @torch.no_grad()
-    def predict(self, inputs, batch_size=32, device=None):
-        """Generates output predictions for the input samples.\n\n    Computation is done in batches."""
+    def predict(self, inputs, batch_size=32, device=None, output_numpy=True):
+        """Generate output predictions for the input samples.\n\n    Computation is done in batches."""
         if self.has_keras_layer and not self.built:
             raise AssertionError("You should call `model.build()` first because the model contains `KerasLayer`.")
 
@@ -183,12 +181,16 @@ class Model(torch.nn.Module):
         for x_batch in data_loader:
             outputs.append(self.forward(x_batch[0].to(device=device)))
 
-        return torch.cat(outputs, dim=0).cpu().numpy()
+        outputs = torch.cat(outputs, dim=0)
+        if output_numpy:
+            return outputs.cpu().numpy()
+        else:
+            return outputs
 
     def save_weights(self, filepath):
-        """Equals to `torch.save(model.state_dict(), filepath)`."""
+        """Equal to `torch.save(model.state_dict(), filepath)`."""
         torch.save(self.state_dict(), filepath)
 
     def load_weights(self, filepath):
-        """Equals to `model.load_state_dict(filepath)`."""
+        """Equal to `model.load_state_dict(filepath)`."""
         self.load_state_dict(filepath)
\ No newline at end of file
